changeset 5988:7c0d4bfd9d2c jdk7u14-b13

8007277: JDK-8002048 testcase fails to compile Summary: sun.* classes is not included to ct.sym file and symbol file have to be ignored Reviewed-by: alanb
author dsamersoff
date Wed, 06 Feb 2013 20:09:33 +0400
parents 83cdc26960b1
children 884f845f48a9 acd5ac174459
files test/sun/management/jdp/JdpTest.sh
diffstat 1 files changed, 14 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/test/sun/management/jdp/JdpTest.sh	Tue Feb 05 18:42:06 2013 -0800
+++ b/test/sun/management/jdp/JdpTest.sh	Wed Feb 06 20:09:33 2013 +0400
@@ -23,7 +23,7 @@
 
 # @test
 # @bug 7169888 
 # @build JdpUnitTest JdpClient JdpDoSomething 
 # @run shell JdpTest.sh --jtreg --no-compile
 # @summary No word Failed expected in the test output
 
@@ -46,6 +46,10 @@
 
 
 _compile(){
+    # If the test run without JTReg, we have to compile it by our self
+    # Under JTReg see @compile statement above
+    # sun.* packages is not included to symbol file lib/ct.sym so we have 
+    # to ignore it
 
     if [ ! -e ${_testclasses} ]
     then
@@ -55,7 +59,8 @@
     rm -f ${_testclasses}/*.class
 
     # Compile testcase
-    ${TESTJAVA}/bin/javac -d ${_testclasses} JdpUnitTest.java \
+    ${COMPILEJAVA}/bin/javac -XDignore.symbol.file -d ${_testclasses} \
+                                             JdpUnitTest.java \
                                              JdpDoSomething.java  \
                                              JdpClient.java
 
@@ -266,6 +271,13 @@
   exit
 fi
 
+# COMPILEJAVA variable is set when we test jre
+if [ "x${COMPILEJAVA}" = "x" ]
+then
+   COMPILEJAVA="${TESTJAVA}"
+fi
+
+
 #------------------------------------------------------------------------------
 # reading parameters
@@ -23,7 +23,7 @@
 # @test
 # @bug 7169888 
-# @build JdpUnitTest JdpClient JdpDoSomething 
+# @compile -XDignore.symbol.file JdpUnitTest.java JdpClient.java JdpDoSomething.java 
 # @run shell JdpTest.sh --jtreg --no-compile
 # @summary No word Failed expected in the test output